@@ -22,6 +22,8 @@
 #include <config.h>
 #endif
 
+#include <boost/bind.hpp>
+
 #include <glibmm/i18n.h>
 #include <gtkmm/grid.h>
 #include <gtkmm/image.h>
@@ -116,8 +118,6 @@ namespace gnote {
 
     // Sensitize the Link toolbar button on text selection
     m_mark_set_timeout = new utils::InterruptableTimeout();
-    m_mark_set_timeout->signal_timeout.connect(
-      sigc::mem_fun(*this, &NoteWindow::update_link_button_sensitivity));
     note.get_buffer()->signal_mark_set().connect(
       sigc::mem_fun(*this, &NoteWindow::on_selection_mark_set));
 
@@ -218,10 +218,6 @@ namespace gnote {
     if(!m_accel_group) {
       m_accel_group = Gtk::AccelGroup::create();
       window.add_accel_group(m_accel_group);
-      m_text_menu->set_accel_group(m_accel_group);
-      m_link_button->add_accelerator("clicked", m_accel_group,
-                                     GDK_KEY_L, Gdk::CONTROL_MASK,
-                                     Gtk::ACCEL_VISIBLE);
 
       if(!m_global_keys) {
         // NOTE: Since some of our keybindings are only
@@ -245,6 +241,8 @@ namespace gnote {
                                       Gtk::ACCEL_VISIBLE);
         m_global_keys->enabled(m_enabled);
       }
+
+      m_text_menu->set_accels(*m_global_keys, m_accel_group);
     }
     else {
       window.add_accel_group(m_accel_group);
@@ -290,6 +288,13 @@ namespace gnote {
         iter != m_widget_actions.end(); ++iter) {
       res.push_back(iter->second);
     }
+
+    res.push_back(Glib::RefPtr<Gtk::Action>());
+    res.push_back(m_important_action);
+    if(m_delete_action) {
+      // Separator before delete
+      res.push_back(m_delete_action);
+    }
     return res;
   }
 
@@ -343,11 +348,6 @@ namespace gnote {
     }
   }
 
-  void NoteWindow::update_link_button_sensitivity()
-  {
-    m_link_button->set_sensitive(!m_note.get_buffer()->get_selection().empty());
-  }
-
   void NoteWindow::on_populate_popup(Gtk::Menu* menu)
   {
     menu->set_accel_group(m_accel_group);
@@ -400,60 +400,34 @@ namespace gnote {
     Gtk::Grid *grid = manage(new Gtk::Grid);
     int grid_col = 0;
 
-    m_pin_image = manage(new Gtk::Image);
-    m_pin_button = manage(new Gtk::ToolButton(*m_pin_image, _("Pin")));
-
-    if(m_note.is_pinned()) {
-      m_pin_image->property_gicon() = get_icon_pin_down();
-      m_pin_button->set_tooltip_text(_("Remove from important notes"));
-    }
-    else {
-      m_pin_image->property_gicon() = get_icon_pin_active();
-      m_pin_button->set_tooltip_text(_("Mark note as important"));
-    }
-
-    m_pin_button->signal_clicked().connect(sigc::mem_fun(*this, &NoteWindow::on_pin_button_clicked));
-    grid->attach(*m_pin_button, grid_col++, 0, 1, 1);
-    notebooks::NotebookManager::obj().signal_note_pin_status_changed
-      .connect(sigc::mem_fun(*this, &NoteWindow::on_pin_status_changed));
-
-    m_link_button = manage(new Gtk::ToolButton(
-                             *manage(new Gtk::Image(Gtk::Stock::JUMP_TO, Gtk::ICON_SIZE_SMALL_TOOLBAR)),
-                             _("Link")));
-    m_link_button->set_use_underline(true);
-    m_link_button->set_is_important(true);
-    m_link_button->set_sensitive(!m_note.get_buffer()->get_selection().empty());
-    m_link_button->signal_clicked().connect(
-      sigc::mem_fun(*this, &NoteWindow::link_button_clicked));
-    m_link_button->set_tooltip_text(_("Link selected text to a new note (Ctrl-L)"));
-    m_link_button->show_all();
-    grid->attach(*m_link_button, grid_col++, 0, 1, 1);
-
-    utils::ToolMenuButton *text_button = manage(new utils::ToolMenuButton(
-        *manage(new Gtk::Image(Gtk::Stock::SELECT_FONT, Gtk::ICON_SIZE_SMALL_TOOLBAR)),
-        _("_Text"), m_text_menu));
-    text_button->set_use_underline(true);
-    text_button->set_is_important(true);
+    Gtk::Button *text_button = manage(new Gtk::Button);
+    Gtk::Image *image = manage(new Gtk::Image);
+    image->property_icon_name() = "insert-text-symbolic";
+    image->property_icon_size() = GTK_ICON_SIZE_MENU;
+    text_button->set_image(*image);
+    text_button->signal_clicked()
+      .connect(boost::bind(sigc::mem_fun(*this, &NoteWindow::on_text_button_clicked), text_button));
+    text_button->property_margin_left() = 12;
     text_button->show_all();
     grid->attach(*text_button, grid_col++, 0, 1, 1);
     text_button->set_tooltip_text(_("Set properties of text"));
 
-    grid->attach(*manage(new Gtk::SeparatorToolItem()), grid_col++, 0, 1, 1);
-
-    m_delete_button = manage(new Gtk::ToolButton(Gtk::Stock::DELETE));
-    m_delete_button->set_use_underline(true);
-    m_delete_button->signal_clicked().connect(
-      sigc::mem_fun(*this, &NoteWindow::on_delete_button_clicked));
-    m_delete_button->show_all();
-    grid->attach(*m_delete_button, grid_col++, 0, 1, 1);
-    m_delete_button->set_tooltip_text(_("Delete this note"));
+    m_important_action = utils::CheckAction::create("mark-important");
+    m_important_action->set_label(_("Is Important"));
+    m_important_action->set_tooltip(_("Toggle notes presence in Important Notes notebook"));
+    m_important_action->checked(m_note.is_pinned());
+    m_important_action->signal_activate().connect(sigc::mem_fun(*this, &NoteWindow::on_pin_button_clicked));
+    notebooks::NotebookManager::obj().signal_note_pin_status_changed
+      .connect(sigc::mem_fun(*this, &NoteWindow::on_pin_status_changed));
 
       // Don't allow deleting the "Start Here" note...
-    if (m_note.is_special()) {
-      m_delete_button->set_sensitive(false);
+    if(!m_note.is_special()) {
+      m_delete_action = Gtk::Action::create("delete-note", _("_Delete"), _("Delete this note"));
+      m_delete_action->signal_activate()
+        .connect(sigc::mem_fun(*this, &NoteWindow::on_delete_button_clicked));
     }
-    grid->attach(*manage(new Gtk::SeparatorToolItem()), grid_col++, 0, 1, 1);
 
+    grid->property_margin_left() = 12;
     grid->show_all();
     return grid;
   }
@@ -616,14 +590,7 @@ namespace gnote {
     if(&m_note != &note) {
       return;
     }
-    if(pinned) {
-      m_pin_image->property_gicon() = get_icon_pin_down();
-      m_pin_button->set_tooltip_text(_("Remove from important notes"));
-    }
-    else {
-      m_pin_image->property_gicon() = get_icon_pin_active();
-      m_pin_button->set_tooltip_text(_("Mark note as important"));
-    }
+    m_important_action->checked(pinned);
   }
 
   void NoteWindow::on_pin_button_clicked()
@@ -631,6 +598,13 @@ namespace gnote {
     m_note.set_pinned(!m_note.is_pinned());
   }
 
+  void NoteWindow::on_text_button_clicked(Gtk::Button *button)
+  {
+    m_text_menu->property_attach_widget() = button;
+    m_text_menu->show_all();
+    utils::popup_menu(*m_text_menu, NULL);
+  }
+
   void NoteWindow::enabled(bool enable)
   {
     m_enabled = enable;
@@ -846,6 +820,7 @@ namespace gnote {
     : Gtk::Menu()
     , m_buffer(buffer)
     , m_undo_manager(undo_manager)
+    , m_link(_("_Link"), true)
     , m_bold(_("<b>_Bold</b>"), true)
     , m_italic(_("<i>_Italic</i>"), true)
     , m_strikeout(_("<s>_Strikeout</s>"), true)
@@ -863,8 +838,6 @@ namespace gnote {
     , m_bullets(_("Bullets"))
     , m_increase_indent(Gtk::Stock::INDENT)
     , m_decrease_indent(Gtk::Stock::UNINDENT)
-    , m_increase_font(_("Increase Font Size"), true)
-    , m_decrease_font(_("Decrease Font Size"), true)
     {
       m_undo = manage(new Gtk::ImageMenuItem (Gtk::Stock::UNDO));
       m_undo->signal_activate().connect(sigc::mem_fun(*this, &NoteTextMenu::undo_clicked));
@@ -884,6 +857,10 @@ namespace gnote {
       undo_manager.signal_undo_changed().connect(sigc::mem_fun(*this, &NoteTextMenu::undo_changed));
 
       Glib::Quark tag_quark("Tag");
+      markup_label(m_link);
+      m_link.signal_activate()
+        .connect(sigc::mem_fun(*this, &NoteTextMenu::link_clicked));
+
       markup_label(m_bold);
       m_bold.set_data(tag_quark, const_cast<char*>("bold"));
       m_bold.signal_activate()
@@ -904,8 +881,6 @@ namespace gnote {
       m_highlight.signal_activate()
         .connect(sigc::bind(sigc::mem_fun(*this, &NoteTextMenu::font_style_clicked), &m_highlight));
 
-      Gtk::SeparatorMenuItem *spacer1 = manage(new Gtk::SeparatorMenuItem());
-
       markup_label(m_normal);
       m_normal.set_active(true);
       m_normal.signal_activate()
@@ -928,14 +903,6 @@ namespace gnote {
 
       m_hidden_no_size.hide();
 
-      m_increase_font.signal_activate()
-        .connect(sigc::mem_fun(*this, &NoteTextMenu::increase_font_clicked));
-
-      m_decrease_font.signal_activate()
-        .connect(sigc::mem_fun(*this, &NoteTextMenu::decrease_font_clicked));
-
-      Gtk::SeparatorMenuItem *spacer2 = manage(new Gtk::SeparatorMenuItem());
-
       m_bullets_clicked_cid = m_bullets.signal_activate()
         .connect(sigc::mem_fun(*this, &NoteTextMenu::toggle_bullets_clicked));
 
@@ -949,26 +916,28 @@ namespace gnote {
 
       refresh_state();
 
+      append(m_link);
+      append(*manage(new Gtk::SeparatorMenuItem()));
       append(m_bold);
       append(m_italic);
       append(m_strikeout);
       append(m_highlight);
-      append(*spacer1);
+      append(*manage(new Gtk::SeparatorMenuItem()));
       append(m_small);
       append(m_normal);
       append(m_large);
       append(m_huge);
-      append(m_increase_font);
-      append(m_decrease_font);
-      append(*spacer2);
+      append(*manage(new Gtk::SeparatorMenuItem()));
       append(m_bullets);
       append(m_increase_indent);
       append(m_decrease_indent);
       show_all ();
     }
 
-  void NoteTextMenu::set_accel_group(const Glib::RefPtr<Gtk::AccelGroup> & accel_group)
+  void NoteTextMenu::set_accels(utils::GlobalKeybinder & keybinder,
+                                const Glib::RefPtr<Gtk::AccelGroup> & accel_group)
   {
+    set_accel_group(accel_group);
     m_undo->add_accelerator("activate", accel_group,
                             GDK_KEY_Z,
                             Gdk::CONTROL_MASK,
@@ -977,6 +946,9 @@ namespace gnote {
                             GDK_KEY_Z,
                             Gdk::CONTROL_MASK | Gdk::SHIFT_MASK,
                             Gtk::ACCEL_VISIBLE);
+    m_link.add_accelerator("activate", accel_group,
+                           GDK_KEY_L, Gdk::CONTROL_MASK,
+                           Gtk::ACCEL_VISIBLE);
     m_bold.add_accelerator("activate", accel_group,
                            GDK_KEY_B,
                            Gdk::CONTROL_MASK,
@@ -993,14 +965,10 @@ namespace gnote {
                                 GDK_KEY_H,
                                 Gdk::CONTROL_MASK,
                                 Gtk::ACCEL_VISIBLE);
-    m_increase_font.add_accelerator("activate", accel_group,
-                                    GDK_KEY_plus,
-                                    Gdk::CONTROL_MASK,
-                                    Gtk::ACCEL_VISIBLE);
-    m_decrease_font.add_accelerator("activate", accel_group,
-                                    GDK_KEY_minus,
-                                    Gdk::CONTROL_MASK,
-                                    Gtk::ACCEL_VISIBLE);
+    keybinder.add_accelerator(sigc::mem_fun(*this, &NoteTextMenu::increase_font_clicked),
+                              GDK_KEY_plus, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
+    keybinder.add_accelerator(sigc::mem_fun(*this, &NoteTextMenu::decrease_font_clicked),
+                              GDK_KEY_minus, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
     m_increase_indent.add_accelerator("activate", accel_group,
                                       GDK_KEY_Right,
                                       Gdk::MOD1_MASK,
@@ -1058,6 +1026,8 @@ namespace gnote {
   {
     m_event_freeze = true;
 
+    Gtk::TextIter start, end;
+    m_link.set_sensitive(m_buffer->get_selection_bounds(start, end));
     m_bold.set_active(m_buffer->is_active_tag("bold"));
     m_italic.set_active(m_buffer->is_active_tag("italic"));
     m_strikeout.set_active(m_buffer->is_active_tag("strikethrough"));
@@ -1080,6 +1050,48 @@ namespace gnote {
     m_event_freeze = false;
   }
 
+  void NoteTextMenu::link_clicked()
+  {
+    if(m_event_freeze) {
+      return;
+    }
+
+    Glib::ustring select = m_buffer->get_selection();
+    if(select.empty()) {
+      return;
+    }
+
+    Glib::ustring body_unused;
+    Glib::ustring title = NoteManagerBase::split_title_from_content(select, body_unused);
+    if(title.empty()) {
+      return;
+    }
+
+    NoteManagerBase & manager(m_buffer->note().manager());
+    NoteBase::Ptr match = manager.find(title);
+    if(!match) {
+      try {
+        match = manager.create(select);
+      }
+      catch(const sharp::Exception & e) {
+        utils::HIGMessageDialog dialog(dynamic_cast<Gtk::Window*>(m_buffer->note().get_window()->host()),
+          GTK_DIALOG_DESTROY_WITH_PARENT,
+          Gtk::MESSAGE_ERROR,  Gtk::BUTTONS_OK,
+          _("Cannot create note"), e.what());
+        dialog.run();
+        return;
+      }
+    }
+    else {
+      Gtk::TextIter start, end;
+      m_buffer->get_selection_bounds(start, end);
+      m_buffer->remove_tag(m_buffer->note().get_tag_table()->get_broken_link_tag(), start, end);
+      m_buffer->apply_tag(m_buffer->note().get_tag_table()->get_link_tag(), start, end);
+    }
+
+    m_buffer->note().get_window()->host()->embed_widget(*static_pointer_cast<Note>(match)->get_window());
+  }
+
   //
   // Font-style menu item activate
   //
