@@ -53,7 +53,7 @@ class NoteTextMenu
 {
 public:
   NoteTextMenu(const Glib::RefPtr<NoteBuffer> & buffer, UndoManager& undo_manager);
-  void set_accel_group(const Glib::RefPtr<Gtk::AccelGroup> &);
+  void set_accels(utils::GlobalKeybinder & keybinder, const Glib::RefPtr<Gtk::AccelGroup> &);
 
   static void markup_label (Gtk::MenuItem & item);
 protected:
@@ -62,6 +62,7 @@ protected:
 private:
   void refresh_sizing_state();
   void refresh_state();
+  void link_clicked();
   void font_style_clicked(Gtk::CheckMenuItem * item);
   void font_size_activated(Gtk::RadioMenuItem *item);
   void undo_clicked();
@@ -78,6 +79,7 @@ private:
   bool                  m_event_freeze;
   Gtk::ImageMenuItem   *m_undo;
   Gtk::ImageMenuItem   *m_redo;
+  Gtk::MenuItem         m_link;
   Gtk::CheckMenuItem    m_bold;
   Gtk::CheckMenuItem    m_italic;
   Gtk::CheckMenuItem    m_strikeout;
@@ -93,8 +95,6 @@ private:
   Gtk::CheckMenuItem    m_bullets;
   Gtk::ImageMenuItem    m_increase_indent;
   Gtk::ImageMenuItem    m_decrease_indent;
-  Gtk::MenuItem         m_increase_font;
-  Gtk::MenuItem         m_decrease_font;
   sigc::connection      m_bullets_clicked_cid;
 };
 
@@ -211,10 +211,6 @@ public:
     {
       return m_editor;
     }
-  Gtk::ToolButton * delete_button() const
-    {
-      return m_delete_button;
-    }
   Gtk::Menu * text_menu() const
     {
       return m_text_menu;
@@ -238,7 +234,6 @@ private:
 
   void on_delete_button_clicked();
   void on_selection_mark_set(const Gtk::TextIter&, const Glib::RefPtr<Gtk::TextMark>&);
-  void update_link_button_sensitivity();
   void on_populate_popup(Gtk::Menu*);
   Gtk::Grid *make_toolbar();
   Gtk::Grid * make_template_bar();
@@ -256,6 +251,7 @@ private:
   void remove_accel_group(Gtk::Window &);
   void on_pin_status_changed(const Note &, bool);
   void on_pin_button_clicked();
+  void on_text_button_clicked(Gtk::Button *button);
 
   Note                        & m_note;
   std::string                   m_name;
@@ -263,14 +259,12 @@ private:
   int                           m_width;
   Glib::RefPtr<Gtk::AccelGroup> m_accel_group;
   Gtk::Grid                    *m_embeddable_toolbar;
-  Gtk::Image                   *m_pin_image;
-  Gtk::ToolButton              *m_pin_button;
-  Gtk::ToolButton              *m_link_button;
   NoteTextMenu                 *m_text_menu;
   Gtk::TextView                *m_editor;
   Gtk::ScrolledWindow          *m_editor_window;
   NoteFindHandler              m_find_handler;
-  Gtk::ToolButton              *m_delete_button;
+  utils::CheckAction::Ptr       m_important_action;
+  Glib::RefPtr<Gtk::Action>     m_delete_action;
   Gtk::Grid                    *m_template_widget;
   Gtk::CheckButton             *m_save_size_check_button;
   Gtk::CheckButton             *m_save_selection_check_button;
